@@ -662,7 +662,8 @@ gst_camera_capturer_update_device_id (GstCameraCapturer *gcc)
 
   if (!g_strcmp0 (gcc->priv->source_element_name, "dv1394src"))
     prop_name = "guid";
-  else if (!g_strcmp0 (gcc->priv->source_element_name, "v4l2src"))
+  else if (!g_strcmp0 (gcc->priv->source_element_name, "v4l2src") ||
+      !g_strcmp0 (gcc->priv->source_element_name, "avfvideosrc"))
     prop_name = "device";
   else if (!g_strcmp0 (gcc->priv->source_element_name, "gsettingsvideosrc"))
     prop_name = NULL;
@@ -1765,7 +1766,8 @@ gst_camera_capturer_enum_devices (gchar * device_name)
   if (!g_strcmp0 (device_name, "dv1394src"))
     prop_name = "guid";
   else if (!g_strcmp0 (device_name, "v4l2src") ||
-      !g_strcmp0 (device_name, "osxvideosrc"))
+      !g_strcmp0 (device_name, "osxvideosrc")  ||
+      !g_strcmp0 (device_name, "avfvideosrc"))
     prop_name = "device";
   else
     prop_name = "device-name";
