@@ -23,6 +23,7 @@ using System.Data;
 using System.Text; //StringBuilder
 using System.IO;   //for Path
 using System.Collections; //ArrayList
+using System.Collections.Generic; //List<T>
 using Mono.Unix;
 
 public class EncoderParams
@@ -602,8 +603,8 @@ public class EncoderSQL
 			str[i++] = "";	//checkboxes
 	
 		str[i++] = count.ToString();
-		str[i++] = exerciseName;
-		str[i++] = laterality;
+		str[i++] = Catalog.GetString(exerciseName);
+		str[i++] = Catalog.GetString(laterality);
 		str[i++] = extraWeight;
 		
 		if(showMeanPower)
@@ -924,6 +925,8 @@ public class EncoderConfiguration {
 	public int extraWeightN; //how much extra weights (inertia)
 	public int extraWeightGrams; //weight of each extra weight (inertia)
 	public double extraWeightLength; //length from center to center (cm) (inertia)
+	
+	public List<double> list_d;	//list of diameters depending on the anchorage position 
 
 
 	public string textDefault = Catalog.GetString("Linear encoder attached to a barbell.") + "\n" + 
@@ -953,6 +956,7 @@ public class EncoderConfiguration {
 		extraWeightN = 0;
 		extraWeightGrams = 0;
 		extraWeightLength = 1;
+		list_d = new List<double>(); 
 	}
 
 	// note: if this changes, change also in:
@@ -967,6 +971,7 @@ public class EncoderConfiguration {
 		has_inertia = false;
 		rotaryFrictionOnAxis = false;
 		gearedDown = 1;
+		list_d = new List<double>(); 
 
 		// ---- LINEAR ----
 		// ---- not inertial
@@ -1119,7 +1124,7 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderFrictionSideInertialLateral;
 			code = "Rotary friction - inertial machine side - horizontal movement";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine when person is moving horizontally.") + "\n" +
-				"*" + Catalog.GetString("Start capture with the string completely unwrapped.") + "*" + "\n" +
+				"*" + Catalog.GetString("Start capture with the rope completely unwrapped.") + "*" + "\n" +
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 
 			has_d = true;
@@ -1163,7 +1168,7 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderFrictionAxisInertialLateral;
 			code = "Rotary friction - inertial machine axis - horizontal movement";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine when person is moving horizontally.") + "\n" +
-				"*" + Catalog.GetString("Start capture with the string completely unwrapped.") + "*" + "\n" +
+				"*" + Catalog.GetString("Start capture with the rope completely unwrapped.") + "*" + "\n" +
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 
 			has_d = true;
@@ -1227,7 +1232,7 @@ public class EncoderConfiguration {
 			image = Constants.FileNameEncoderAxisInertialLateral;
 			code = "Rotary axis - inertial machine - horizontal movement";
 			text = Catalog.GetString("Rotary axis encoder on inertial machine when person is moving horizontally.") + "\n" +
-				"*" + Catalog.GetString("Start capture with the string completely unwrapped.") + "*" + "\n" +
+				"*" + Catalog.GetString("Start capture with the rope completely unwrapped.") + "*" + "\n" +
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 
 			has_d = true;
@@ -1266,12 +1271,33 @@ public class EncoderConfiguration {
 			this.extraWeightN = 	Convert.ToInt32(strFull[8]);
 			this.extraWeightGrams = Convert.ToInt32(strFull[9]);
 			this.extraWeightLength = Convert.ToDouble(Util.ChangeDecimalSeparator(strFull[10]));
+			if(strFull.Length > 11) //this param starts at 1.5.3
+				this.list_d = readList_d(strFull[11]);
 		} else {
 			this.inertiaTotal = 	inertiaMachine;
 			this.extraWeightN = 	0;
 			this.extraWeightGrams = 0;
 			this.extraWeightLength = 1;
 		}
+
+		//if we load a signal previous to 1.5.3, put d in list_d to have something to be sent to R
+		if(this.list_d.Count == 0)
+			this.list_d.Add(d);
+		else if (this.list_d.Count == 1 && this.list_d[0] == 0) {
+			//check if diameter is zero is safest because some tests have been done while list_d has been completely implemented
+			this.list_d[0] = this.d;
+		}
+	}
+	//list_d contains the different diameters (byt eh anchorages). They are stored as '_'
+	private List<double> readList_d(string listFromSQL) 
+	{
+		List<double> l = new List<double>(); 
+		string [] strFull = listFromSQL.Split(new char[] {'_'});
+		foreach (string s in strFull) {
+			double d = Convert.ToDouble(Util.ChangeDecimalSeparator(s));
+			l.Add(d);
+		}
+		return l;
 	}
 
 	//called on capture, recalculate, load
@@ -1328,10 +1354,20 @@ public class EncoderConfiguration {
 				inertiaTotal.ToString() + sep + 
 				extraWeightN.ToString() + sep + 
 				extraWeightGrams.ToString() + sep +
-				extraWeightLength.ToString()
+				extraWeightLength.ToString() + sep +
+				writeList_d(list_d)
 				;
 		}
 	}
+	private string writeList_d(List<double> l) {
+		string str = "";
+		string sep = "";
+		foreach(double d in l) {
+			str += sep + Util.ConvertToPoint(d);
+			sep = "_";
+		}
+		return str;
+	}
 	
 	//just to show on a treeview	
 	public string ToStringPretty() {
