@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -165,7 +165,7 @@ public class EventExecute
 	//public virtual void Simulate(Random randSent)
 	public virtual void SimulateInitValues(Random randSent)
 	{
-		Log.WriteLine("From event.cs");
+		LogB.Information("From event.cs");
 
 		//look at the override on jump.cs for a sample
 		
@@ -192,7 +192,7 @@ public class EventExecute
 			try {
 				ok = cp.Read_platform(out myPlatformState);
 			} catch {
-				Log.WriteLine("Manage called after finishing constructor, do later");
+				LogB.Warning("Manage called after finishing constructor, do later");
 			}
 			Thread.Sleep(timeWait); //wait 50ms
 			count += timeWait;
@@ -234,26 +234,23 @@ public class EventExecute
 		//then thread is dead
 
 		if ( ! thread.IsAlive || cancel) {
+			LogB.ThreadEnding(); 
 			fakeButtonThreadDyed.Click();
-			Log.Write("dying");
 
+			LogB.ThreadEnded(); 
 			return false;
 		}
 	
 		Thread.Sleep (50);
-		//Log.Write(thread.ThreadState.ToString());
+		//LogB.Debug(thread.ThreadState.ToString());
 		return true;
 	}
 
-
-	public void StopThread() {
-		/*
-		Log.WriteLine("----------ABORTING----------");
+	public void ThreadAbort() {
 		thread.Abort();
-		Log.WriteLine("----------ABORTED-----------");
-		*/
 	}
 
+
 	protected void initializeTimer () {
 		//put onTimer count to 0 for moving the time progressBar (activiy mode)	
 		//also in simulated, allows to change platform state
@@ -312,9 +309,9 @@ public class EventExecute
 		if(needUpdateGraph) {
 			//solve problems when runAnalysis ended and tries to paint window
 			if(needUpdateGraphType == eventType.MULTICHRONOPIC && type == Constants.RunAnalysisName && finish) 
-				Console.WriteLine("is MC, RA, finished!");	
+				LogB.Information("is MC, RA, finished!");	
 			else if(needUpdateGraphType == eventType.MULTICHRONOPIC && type == Constants.RunAnalysisName && ! finish) {
-				Console.WriteLine("is MC, RA, NOT finished!");	
+				LogB.Information("is MC, RA, NOT finished!");	
 				updateGraph();
 			} else
 				updateGraph();
@@ -366,7 +363,7 @@ public class EventExecute
 			progressbarEventOrTimeExecution (egd.Progressbar_time, percentageMode, egd.Label_time_value, events);
 	}
 
-	protected void progressbarEventOrTimeExecution (Gtk.ProgressBar progressbar, bool percentageMode, Gtk.Label label_value, double events)
+	private void progressbarEventOrTimeExecution (Gtk.ProgressBar progressbar, bool percentageMode, Gtk.Label label_value, double events)
 	{
 		if(progressbarLimit == -1) {	//unlimited event (until 'finish' is clicked)
 			progressbar.Pulse();
@@ -436,13 +433,13 @@ public class EventExecute
 	}
 
 	protected void simulateChangePlatform() {
-		Log.Write("Changing!");
-		Log.WriteLine(string.Format("PRE timeLast: {0}, timerCount: {1}, timeAccumulated: {2}", simulatedTimeLast, timerCount, simulatedTimeAccumulatedBefore));
+		LogB.Information("Changing!");
+		LogB.Information(string.Format("PRE timeLast: {0}, timerCount: {1}, timeAccumulated: {2}", simulatedTimeLast, timerCount, simulatedTimeAccumulatedBefore));
 
 		simulatedTimeLast = timerCount - simulatedTimeAccumulatedBefore;
 		//simulatedTimeAccumulatedBefore = timerCount;
 		simulatedTimeAccumulatedBefore = Math.Round(timerCount,2);
-		Log.WriteLine(string.Format("POST: timeLast: {0}, timerCount: {1}, timeAccumulated: {2}", simulatedTimeLast, timerCount, simulatedTimeAccumulatedBefore));
+		LogB.Information(string.Format("POST: timeLast: {0}, timerCount: {1}, timeAccumulated: {2}", simulatedTimeLast, timerCount, simulatedTimeAccumulatedBefore));
 
 		//change the boolean who points to 'which are the MINs and the MAXs
 		simulatedCurrentTimeIntervalsAreContact = ! simulatedCurrentTimeIntervalsAreContact;
@@ -452,7 +449,7 @@ public class EventExecute
 		else
 			platformState = Chronopic.Plataforma.ON;
 
-		Log.WriteLine("Changed!");
+		LogB.Information("Changed!");
 	}
 			
 	private void updateGraph() {
@@ -497,6 +494,10 @@ public class EventExecute
 		
 		//event will be raised, and managed in chronojump.cs
 		fakeButtonFinished.Click();
+			
+		//event will be raised, and managed in chronojump.cs
+		//calls sensitiveGuiEventDone()
+		fakeButtonThreadDyed.Click();
 	}
 
 	protected void chronopicHasBeenDisconnected() {
@@ -513,7 +514,7 @@ public class EventExecute
 		return false;
 	}
 	public virtual void MultiChronopicWrite(bool tempTable) {
-		Console.WriteLine("at event.cs");
+		LogB.Information("at event.cs");
 	}
 			
 	public Gtk.Button FakeButtonUpdateGraph {
