@@ -36,8 +36,31 @@ public partial class ChronoJumpWindow
 
 	//returns curves num
 	//capture has single and multiple selection in order to save curves... Analyze only shows data.
+	//TODO: do not create this for every repetition while we are executing. Just add the new row
 	private int createTreeViewEncoderCapture(List<string> contents) 
 	{
+		int curvesCount = 0;
+		bool headers = true;
+		if(! encoderUpdateTreeViewWhileCapturing && capturingCsharp == encoderCaptureProcess.CAPTURING) {
+			//just count how much curves and return
+			foreach(string line in contents)
+			{
+				if(headers) {
+					headers = false;
+					continue;
+				}
+			
+				if (line == null)
+					break;
+			
+				curvesCount ++;
+			}
+			return curvesCount;
+		}
+
+
+		LogB.Debug("At createTreeViewEncoderCapture");
+
 		bool showStartAndDuration = encoderCaptureOptionsWin.check_show_start_and_duration.Active;
 
 		string [] columnsString = {
@@ -59,11 +82,16 @@ public partial class ChronoJumpWindow
 
 		encoderCaptureCurves = new ArrayList ();
 
-		int curvesCount = 0;
-		bool headers = true;
+		headers = true;
 		foreach(string line in contents)
 		{
-			LogB.Debug(line);
+			/*
+			 * don't print this because on capture, if 100 repetitions are captured
+			 * it will be printing 97 lines, 98, 99, 100 (with a small time)
+			 * can be too much for certain computers
+			 */
+			//LogB.Debug(line);
+
 			if(headers) {
 				headers = false;
 				continue;
@@ -76,7 +104,13 @@ public partial class ChronoJumpWindow
 
 			string [] cells = line.Split(new char[] {','});
 			cells = fixDecimals(cells);
-			LogB.Error(Util.StringArrayToString(cells, ":"));
+			
+			/*
+			 * don't print this because on capture, if 100 repetitions are captured
+			 * it will be printing 97 lines, 98, 99, 100 (with a small time)
+			 * can be too much for certain computers
+			 */
+			//LogB.Error(Util.StringArrayToString(cells, ":"));
 
 			encoderCaptureCurves.Add (new EncoderCurve (
 						false,				//user need to mark to save them
@@ -224,8 +258,9 @@ public partial class ChronoJumpWindow
 
 	void ItemToggled(object o, ToggledArgs args) 
 	{
-		//cannot toggle item while capturing
-		if(capturingCsharp == encoderCaptureProcess.CAPTURING)
+		//cannot toggle item while capturing or recalculating
+		if(capturingCsharp == encoderCaptureProcess.CAPTURING ||
+				encoderRProcAnalyze.status == EncoderRProc.Status.RUNNING)
 			return;
 
 		TreeIter iter;
