@@ -270,6 +270,8 @@ class SqliteEncoder : Sqlite
 				(Constants.EncoderConfigurationNames) 
 				Enum.Parse(typeof(Constants.EncoderConfigurationNames), strFull[0]) );
 			econf.ReadParamsFromSQL(strFull);
+
+			LogB.Debug("EncoderConfiguration = " + econf.ToStringOutput(EncoderConfiguration.Outputs.SQL));
 			
 			//if there's no video, will be "".
 			//if there's video, will be with full path
@@ -558,6 +560,10 @@ class SqliteEncoder : Sqlite
 		addEncoderJumpExercise();
 		addEncoderInclinatedExercises();
 	}
+
+	//written just to have the names translated
+	private string ExerciseTranslatedBenchPress = Catalog.GetString("Bench press");
+	private string ExerciseTranslatedSquat = Catalog.GetString("Squat");
 	
 	protected internal static void addEncoderFreeExercise()
 	{
